==> zio-aws-pinpointemail_2.12-5.19.8.3-sources.jar: zio/aws/pinpointemail/model/PutDedicatedIpWarmupAttributesRequest.scala <==
package zio.aws.pinpointemail.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpointemail.model.primitives.{Percentage100Wrapper, Ip}
import scala.jdk.CollectionConverters._
final case class PutDedicatedIpWarmupAttributesRequest(
    ip: Ip,
    warmupPercentage: Percentage100Wrapper
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpointemail.model.PutDedicatedIpWarmupAttributesRequest = {
    import PutDedicatedIpWarmupAttributesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpointemail.model.PutDedicatedIpWarmupAttributesRequest
      .builder()
      .ip(Ip.unwrap(ip): java.lang.String)
      .warmupPercentage(Percentage100Wrapper.unwrap(warmupPercentage): Integer)
      .build()
  }
  def asReadOnly
      : zio.aws.pinpointemail.model.PutDedicatedIpWarmupAttributesRequest.ReadOnly =
    zio.aws.pinpointemail.model.PutDedicatedIpWarmupAttributesRequest
      .wrap(buildAwsValue())
}
object PutDedicatedIpWarmupAttributesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpointemail.model.PutDedicatedIpWarmupAttributesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.pinpointemail.model.PutDedicatedIpWarmupAttributesRequest =
      zio.aws.pinpointemail.model
        .PutDedicatedIpWarmupAttributesRequest(ip, warmupPercentage)
    def ip: Ip
    def warmupPercentage: Percentage100Wrapper
    def getIp: ZIO[Any, Nothing, Ip] = ZIO.succeed(ip)
    def getWarmupPercentage: ZIO[Any, Nothing, Percentage100Wrapper] =
      ZIO.succeed(warmupPercentage)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpointemail.model.PutDedicatedIpWarmupAttributesRequest
  ) extends zio.aws.pinpointemail.model.PutDedicatedIpWarmupAttributesRequest.ReadOnly {
    override val ip: Ip = zio.aws.pinpointemail.model.primitives.Ip(impl.ip())
    override val warmupPercentage: Percentage100Wrapper =
      zio.aws.pinpointemail.model.primitives
        .Percentage100Wrapper(impl.warmupPercentage())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpointemail.model.PutDedicatedIpWarmupAttributesRequest
  ): zio.aws.pinpointemail.model.PutDedicatedIpWarmupAttributesRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-pinpointemail_3-6.20.47.1-sources.jar: zio/aws/pinpointemail/model/PutDedicatedIpWarmupAttributesRequest.scala <==
package zio.aws.pinpointemail.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpointemail.model.primitives.{Percentage100Wrapper, Ip}
import scala.jdk.CollectionConverters.*
final case class PutDedicatedIpWarmupAttributesRequest(
    ip: Ip,
    warmupPercentage: Percentage100Wrapper
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpointemail.model.PutDedicatedIpWarmupAttributesRequest = {
    import PutDedicatedIpWarmupAttributesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpointemail.model.PutDedicatedIpWarmupAttributesRequest
      .builder()
      .ip(Ip.unwrap(ip): java.lang.String)
      .warmupPercentage(Percentage100Wrapper.unwrap(warmupPercentage): Integer)
      .build()
  }
  def asReadOnly
      : zio.aws.pinpointemail.model.PutDedicatedIpWarmupAttributesRequest.ReadOnly =
    zio.aws.pinpointemail.model.PutDedicatedIpWarmupAttributesRequest
      .wrap(buildAwsValue())
}
object PutDedicatedIpWarmupAttributesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpointemail.model.PutDedicatedIpWarmupAttributesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.pinpointemail.model.PutDedicatedIpWarmupAttributesRequest =
      zio.aws.pinpointemail.model
        .PutDedicatedIpWarmupAttributesRequest(ip, warmupPercentage)
    def ip: Ip
    def warmupPercentage: Percentage100Wrapper
    def getIp: ZIO[Any, Nothing, Ip] = ZIO.succeed(ip)
    def getWarmupPercentage: ZIO[Any, Nothing, Percentage100Wrapper] =
      ZIO.succeed(warmupPercentage)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpointemail.model.PutDedicatedIpWarmupAttributesRequest
  ) extends zio.aws.pinpointemail.model.PutDedicatedIpWarmupAttributesRequest.ReadOnly {
    override val ip: Ip = zio.aws.pinpointemail.model.primitives.Ip(impl.ip())
    override val warmupPercentage: Percentage100Wrapper =
      zio.aws.pinpointemail.model.primitives
        .Percentage100Wrapper(impl.warmupPercentage())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpointemail.model.PutDedicatedIpWarmupAttributesRequest
  ): zio.aws.pinpointemail.model.PutDedicatedIpWarmupAttributesRequest.ReadOnly =
    new Wrapper(impl)
}
